package com.ruoyi.model.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.model.mapper.WithdrawalConfigMapper;
import com.ruoyi.model.domain.WithdrawalConfig;
import com.ruoyi.model.service.IWithdrawalConfigService;

/**
 * 钱包提现配置Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
@Service
public class WithdrawalConfigServiceImpl implements IWithdrawalConfigService 
{
    @Autowired
    private WithdrawalConfigMapper withdrawalConfigMapper;

    /**
     * 查询钱包提现配置
     * 
     * @param id 钱包提现配置主键
     * @return 钱包提现配置
     */
    @Override
    public WithdrawalConfig selectWithdrawalConfigById(Long id)
    {
        return withdrawalConfigMapper.selectWithdrawalConfigById(id);
    }

    /**
     * 查询钱包提现配置列表
     * 
     * @param withdrawalConfig 钱包提现配置
     * @return 钱包提现配置
     */
    @Override
    public List<WithdrawalConfig> selectWithdrawalConfigList(WithdrawalConfig withdrawalConfig)
    {
        return withdrawalConfigMapper.selectWithdrawalConfigList(withdrawalConfig);
    }

    /**
     * 新增钱包提现配置
     * 
     * @param withdrawalConfig 钱包提现配置
     * @return 结果
     */
    @Override
    public int insertWithdrawalConfig(WithdrawalConfig withdrawalConfig)
    {
        return withdrawalConfigMapper.insertWithdrawalConfig(withdrawalConfig);
    }

    /**
     * 修改钱包提现配置
     * 
     * @param withdrawalConfig 钱包提现配置
     * @return 结果
     */
    @Override
    public int updateWithdrawalConfig(WithdrawalConfig withdrawalConfig)
    {
        return withdrawalConfigMapper.updateWithdrawalConfig(withdrawalConfig);
    }

    /**
     * 批量删除钱包提现配置
     * 
     * @param ids 需要删除的钱包提现配置主键
     * @return 结果
     */
    @Override
    public int deleteWithdrawalConfigByIds(Long[] ids)
    {
        return withdrawalConfigMapper.deleteWithdrawalConfigByIds(ids);
    }

    /**
     * 删除钱包提现配置信息
     * 
     * @param id 钱包提现配置主键
     * @return 结果
     */
    @Override
    public int deleteWithdrawalConfigById(Long id)
    {
        return withdrawalConfigMapper.deleteWithdrawalConfigById(id);
    }

    @Override
    public List<WithdrawalConfig> getWithdrawalConfigList() {
        return withdrawalConfigMapper.getWithdrawalConfigList();
    }
}
