package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.WithdrawalConfig;
import com.ruoyi.model.service.IWithdrawalConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 钱包提现配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
@RestController
@RequestMapping("/model/WithdrawalConfig")
public class WithdrawalConfigController extends BaseController
{
    @Autowired
    private IWithdrawalConfigService withdrawalConfigService;

    /**
     * 查询钱包提现配置列表
     */
    @PreAuthorize("@ss.hasPermi('model:WithdrawalConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(WithdrawalConfig withdrawalConfig)
    {
        startPage();
        List<WithdrawalConfig> list = withdrawalConfigService.selectWithdrawalConfigList(withdrawalConfig);
        return getDataTable(list);
    }

    /**
     * 导出钱包提现配置列表
     */
    @PreAuthorize("@ss.hasPermi('model:WithdrawalConfig:export')")
    @Log(title = "钱包提现配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WithdrawalConfig withdrawalConfig) throws IOException {
        List<WithdrawalConfig> list = withdrawalConfigService.selectWithdrawalConfigList(withdrawalConfig);
        ExcelUtil<WithdrawalConfig> util = new ExcelUtil<WithdrawalConfig>(WithdrawalConfig.class);
        util.exportExcel(response, list, "钱包提现配置数据");
    }

    /**
     * 获取钱包提现配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:WithdrawalConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(withdrawalConfigService.selectWithdrawalConfigById(id));
    }

    /**
     * 新增钱包提现配置
     */
    @PreAuthorize("@ss.hasPermi('model:WithdrawalConfig:add')")
    @Log(title = "钱包提现配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WithdrawalConfig withdrawalConfig)
    {
        return toAjax(withdrawalConfigService.insertWithdrawalConfig(withdrawalConfig));
    }

    /**
     * 修改钱包提现配置
     */
    @PreAuthorize("@ss.hasPermi('model:WithdrawalConfig:edit')")
    @Log(title = "钱包提现配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WithdrawalConfig withdrawalConfig)
    {
        return toAjax(withdrawalConfigService.updateWithdrawalConfig(withdrawalConfig));
    }

    /**
     * 删除钱包提现配置
     */
    @PreAuthorize("@ss.hasPermi('model:WithdrawalConfig:remove')")
    @Log(title = "钱包提现配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(withdrawalConfigService.deleteWithdrawalConfigByIds(ids));
    }
}
